<?php
/**
 * License Manager Class
 * 
 * Manages license checks and support status
 */

class TMPL_License_Manager {
    const SUPPORT_STATUS_KEY = 'tmpl_support_status';
    const CHECK_COUNT_KEY = 'tmpl_update_check_count';
    const CHECK_COUNT_DATE_KEY = 'tmpl_update_check_date';
    const MAX_CHECKS_PER_DAY = 5;

    /**
     * Проверяет, активна ли поддержка
     */
    public function is_support_active() {
        $status = $this->get_support_status();
        return $status && isset($status['is_active']) && $status['is_active'];
    }

    /**
     * Получает статус поддержки
     */
    public function get_support_status() {
        return get_option(self::SUPPORT_STATUS_KEY, null);
    }

    /**
     * Обновляет статус поддержки
     */
    public function update_support_status($purchase_date, $support_end_date) {
        $now = new DateTime();
        $end_date = new DateTime($support_end_date);
        
        $status = [
            'purchase_date' => $purchase_date,
            'support_end_date' => $support_end_date,
            'is_active' => ($now < $end_date),
            'days_remaining' => max(0, $end_date->diff($now)->days)
        ];
        
        update_option(self::SUPPORT_STATUS_KEY, $status);
        return $status;
    }

    /**
     * Проверяет, можно ли проверять обновления
     */
    public function can_check_updates() {
        $today = date('Y-m-d');
        $last_check_date = get_option(self::CHECK_COUNT_DATE_KEY);
        
        // Если дата последней проверки не сегодня, сбрасываем счетчик
        if ($last_check_date !== $today) {
            update_option(self::CHECK_COUNT_KEY, 0);
            update_option(self::CHECK_COUNT_DATE_KEY, $today);
            return true;
        }
        
        $check_count = (int)get_option(self::CHECK_COUNT_KEY, 0);
        return $check_count < self::MAX_CHECKS_PER_DAY;
    }

    /**
     * Увеличивает счетчик проверок
     */
    public function increment_check_count() {
        $today = date('Y-m-d');
        $last_check_date = get_option(self::CHECK_COUNT_DATE_KEY);
        
        // Если дата последней проверки не сегодня, сбрасываем счетчик
        if ($last_check_date !== $today) {
            update_option(self::CHECK_COUNT_KEY, 1);
            update_option(self::CHECK_COUNT_DATE_KEY, $today);
            return;
        }
        
        $check_count = (int)get_option(self::CHECK_COUNT_KEY, 0);
        update_option(self::CHECK_COUNT_KEY, $check_count + 1);
    }

    /**
     * Получает оставшееся количество проверок на сегодня
     */
    public function get_remaining_checks() {
        $today = date('Y-m-d');
        $last_check_date = get_option(self::CHECK_COUNT_DATE_KEY);
        
        if ($last_check_date !== $today) {
            return self::MAX_CHECKS_PER_DAY;
        }
        
        $check_count = (int)get_option(self::CHECK_COUNT_KEY, 0);
        return max(0, self::MAX_CHECKS_PER_DAY - $check_count);
    }
}
