<?php
/**
 * Plugin Name: TMPL Updater
 * Description: Automatic updates for Templines themes and plugins
 * Version: 1.0.2
 * Author: Templines
 * Text Domain: tmpl-updater
 */


if (!defined('ABSPATH')) exit;


require 'plugin-update-checker/plugin-update-checker.php';
$MyUpdateChecker = Puc_v4_Factory::buildUpdateChecker(
    'http://assets.templines.com/plugins/tmpl-updater.json',
    __FILE__,
    'tmpl-updater'
);



require_once(ABSPATH . 'wp-admin/includes/class-wp-upgrader.php');

// Создаем свой класс для skin, чтобы перехватить вывод
class TMPL_Upgrader_Skin extends WP_Upgrader_Skin {
    public function feedback($string, ...$args) {
        // Отключаем вывод
    }
    
    public function header() {
        // Отключаем вывод
    }
    
    public function footer() {
        // Отключаем вывод
    }
}

class TMPL_Updater {
    private $plugin_list;
    private $theme_info;
    private $license_manager;
    private $updates_data;

    public function __construct() {
        // Инициализируем списки плагинов и тем для проверки обновлений
        $this->plugin_list = [
            'templines-helper-core' => [
                'name' => 'Templines Helper Core',
                'url' => 'https://assets.templines.com/plugins/theme/autozone/templines-helper-core.json'
            ],
            'pix-auto-deal' => [
                'name' => 'Pix Auto Deal',
                'url' => 'https://assets.templines.com/plugins/theme/autozone/pix-auto-deal.json'
            ],

        ];

        $this->theme_info = [
            'autozone' => [
                'name' => 'Autozone Theme',
                'url' => 'https://assets.templines.com/plugins/theme/autozone/theme.json'
            ]
        ];

        // Загружаем сохраненные данные об обновлениях
        $this->updates_data = get_option('tmpl_updates', []);

        add_action('admin_menu', [$this, 'add_menu_page']);
        add_action('admin_post_tmpl_check_updates', [$this, 'check_updates']);
        add_action('admin_post_tmpl_update_all', [$this, 'update_all']);
        add_action('admin_post_tmpl_delete_license', [$this, 'delete_license']);
        add_action('admin_post_tmpl_verify_license', [$this, 'verify_license']);

        // Интеграция с системой обновлений WordPress
        add_filter('pre_set_site_transient_update_plugins', [$this, 'inject_plugin_updates']);
        add_filter('pre_set_site_transient_update_themes', [$this, 'inject_theme_updates']);
        add_filter('plugins_api', [$this, 'plugin_info'], 20, 3);
        add_filter('site_transient_update_plugins', [$this, 'inject_plugin_updates']);
        add_filter('site_transient_update_themes', [$this, 'inject_theme_updates']);
    }

    public function inject_plugin_updates($transient) {
        if (empty($transient->checked)) {
            return $transient;
        }

        foreach ($this->updates_data as $slug => $update) {
            if (strpos($slug, 'theme_') === 0) {
                continue;
            }

            if (!empty($update['has_update'])) {
                $plugin_file = $this->get_plugin_file($slug);
                $item = (object)[
                    'id' => $update['slug'],
                    'slug' => $update['slug'],
                    'plugin' => $plugin_file,
                    'new_version' => $update['version'],
                    'url' => $update['download_url'],
                    'package' => $update['download_url'],
                    'icons' => [],
                    'banners' => [],
                    'banners_rtl' => [],
                    'tested' => '',
                    'requires_php' => '',
                    'compatibility' => new stdClass,
                    'author' => $update['author'],
                    'sections' => $update['sections'],
                    'upgrade_notice' => $update['upgrade_notice']
                ];
                $transient->response[$plugin_file] = $item;
            }
        }

        return $transient;
    }

    public function inject_theme_updates($transient) {
        if (empty($transient->checked)) {
            return $transient;
        }

        foreach ($this->updates_data as $slug => $update) {
            if (strpos($slug, 'theme_') !== 0) {
                continue;
            }

            if (!empty($update['has_update'])) {
                $theme_slug = str_replace('theme_', '', $slug);
                $item = [
                    'theme' => $theme_slug,
                    'new_version' => $update['version'],
                    'url' => $update['details_url'],
                    'package' => $update['download_url']
                ];
                $transient->response[$theme_slug] = $item;
            }
        }

        return $transient;
    }

    public function plugin_info($res, $action, $args) {
        if ($action !== 'plugin_information') {
            return $res;
        }

        foreach ($this->plugin_list as $slug => $plugin) {
            if ($args->slug === $slug) {
                $update = isset($this->updates_data[$slug]) ? $this->updates_data[$slug] : null;
                if ($update) {
                    return (object)[
                        'name' => $update['name'],
                        'slug' => $slug,
                        'version' => $update['version'],
                        'download_link' => $update['download_url'],
                        'sections' => $update['sections'] ?? []
                    ];
                }
            }
        }

        return $res;
    }

    private function get_plugin_file($slug) {
        $plugin_files = [
            'templines-helper-core' => 'templines-helper-core/templines-helping-core.php',
            'pix-auto-deal' => 'pix-auto-deal/pixad-autos.php',
            'pix-booking-auto' => 'Pixbooking/pix-booking-auto.php'
        ];
        return isset($plugin_files[$slug]) ? $plugin_files[$slug] : $slug;
    }

    public function add_menu_page() {
        add_menu_page(
            __('TMPL Updater', 'tmpl-updater'),
            __('TMPL Updater', 'tmpl-updater'),
            'manage_options',
            'tmpl-updater',
            [$this, 'render_page'],
            'dashicons-update'
        );
    }

    public function render_page() {
        include plugin_dir_path(__FILE__) . 'views/updater.php';
    }

    public function delete_license() {
        if (!current_user_can('manage_options')) {
            wp_die(__('You do not have sufficient permissions to access this page.'));
        }

        check_admin_referer('tmpl_delete_license');

        delete_option('tmpl_license_key');
        delete_option('tmpl_product_name');
        delete_option('tmpl_support_status');
        delete_option('tmpl_updates');
        $this->updates_data = [];

        // Сбрасываем кэш обновлений WordPress
        delete_site_transient('update_plugins');
        delete_site_transient('update_themes');

        wp_redirect(admin_url('admin.php?page=tmpl-updater&license=deleted'));
        exit;
    }

    public function verify_license() {
        if (!current_user_can('manage_options')) {
            wp_die(__('You do not have sufficient permissions to access this page.'));
        }

        check_admin_referer('tmpl_verify_license');

        $license_key = sanitize_text_field($_POST['license_key']);
        if (empty($license_key)) {
            wp_redirect(admin_url('admin.php?page=tmpl-updater&error=empty_license'));
            exit;
        }

        // Здесь должна быть проверка лицензии через API
        // Демо-реализация
        update_option('tmpl_license_key', $license_key);
        update_option('tmpl_product_name', 'Autozone Theme');

        // Проверяем статус поддержки сразу после активации лицензии
        $support_status = $this->check_support_status();
        update_option('tmpl_support_status', $support_status);

        wp_redirect(admin_url('admin.php?page=tmpl-updater&license=verified'));
        exit;
    }

    public function check_updates() {
        if (!current_user_can('manage_options')) {
            wp_die(__('You do not have sufficient permissions to access this page.'));
        }

        check_admin_referer('tmpl_check_updates');

        $updates_data = [];
        $has_errors = false;
        $errors = [];
        $debug_info = [];

        // Проверяем статус поддержки
        $support_status = $this->check_support_status();
        update_option('tmpl_support_status', $support_status);
        
        // Сохраняем время последней проверки
        update_option('tmpl_last_check_time', current_time('mysql'));

        // Проверяем обновления для плагинов
        if (!function_exists('get_plugins')) {
            require_once ABSPATH . 'wp-admin/includes/plugin.php';
        }
        $installed_plugins = get_plugins();
        $debug_info['installed_plugins'] = $installed_plugins;

        foreach ($this->plugin_list as $slug => $plugin) {
            try {
                $plugin_file = $this->get_plugin_file($slug);
                $debug_info[$slug] = [
                    'plugin_file' => $plugin_file,
                    'installed' => isset($installed_plugins[$plugin_file]),
                    'url' => $plugin['url']
                ];

                if (!isset($installed_plugins[$plugin_file])) {
                    $debug_info[$slug]['status'] = 'Plugin not installed';
                    continue; // Пропускаем, если плагин не установлен
                }

                $current_version = $installed_plugins[$plugin_file]['Version'];
                $debug_info[$slug]['current_version'] = $current_version;

                // Получаем данные об обновлении с сервера
                $response = wp_remote_get($plugin['url']);
                if (is_wp_error($response)) {
                    throw new Exception($response->get_error_message());
                }

                $response_code = wp_remote_retrieve_response_code($response);
                $debug_info[$slug]['response_code'] = $response_code;

                if ($response_code !== 200) {
                    throw new Exception('Server returned code: ' . $response_code);
                }

                $body = wp_remote_retrieve_body($response);
                $data = json_decode($body, true);
                
                $debug_info[$slug]['parsed_data'] = $data;
                $debug_info[$slug]['has_update'] = version_compare($data['version'], $current_version, '>');

                $updates_data[$slug] = [
                    'name' => $data['name'] ?? $plugin['name'],
                    'slug' => $data['slug'] ?? $slug,
                    'current_version' => $current_version,
                    'version' => $data['version'],
                    'download_url' => $data['download_url'],
                    'has_update' => version_compare($data['version'], $current_version, '>'),
                    'upgrade_notice' => $data['upgrade_notice'] ?? '',
                    'sections' => $data['sections'] ?? [],
                    'author' => $data['author'] ?? 'Templines'
                ];
            } catch (Exception $e) {
                $has_errors = true;
                $errors[] = sprintf('Error checking updates for %s: %s', $plugin['name'], $e->getMessage());
                $debug_info[$slug]['error'] = $e->getMessage();
            }
        }

        // Проверяем обновления для темы
        $theme = wp_get_theme('autozone');
        if ($theme->exists()) {
            $current_theme_version = $theme->get('Version');
            $debug_info['theme'] = [
                'exists' => true,
                'current_version' => $current_theme_version
            ];

            foreach ($this->theme_info as $slug => $theme_data) {
                try {
                    // Получаем данные об обновлении с сервера
                    $response = wp_remote_get($theme_data['url']);
                    if (is_wp_error($response)) {
                        throw new Exception($response->get_error_message());
                    }

                    $response_code = wp_remote_retrieve_response_code($response);
                    $debug_info['theme']['response_code'] = $response_code;

                    if ($response_code !== 200) {
                        throw new Exception('Server returned code: ' . $response_code);
                    }

                    $body = wp_remote_retrieve_body($response);
                    $data = json_decode($body, true);
                    
                    $debug_info['theme']['parsed_data'] = $data;
                    $debug_info['theme']['has_update'] = version_compare($data['version'], $current_theme_version, '>');

                    $updates_data['theme_' . $slug] = [
                        'name' => $theme_data['name'],
                        'current_version' => $current_theme_version,
                        'version' => $data['version'],
                        'download_url' => $data['download_url'],
                        'has_update' => version_compare($data['version'], $current_theme_version, '>'),
                        'details_url' => $data['details_url'] ?? ''
                    ];
                } catch (Exception $e) {
                    $has_errors = true;
                    $errors[] = sprintf('Error checking updates for %s theme: %s', $theme_data['name'], $e->getMessage());
                    $debug_info['theme']['error'] = $e->getMessage();
                }
            }
        } else {
            $debug_info['theme'] = ['exists' => false];
        }

        // Сохраняем данные об обновлениях
        $this->updates_data = $updates_data;
        update_option('tmpl_updates', $updates_data);
        update_option('tmpl_debug_info', $debug_info);

        // Сбрасываем кэш обновлений WordPress
        delete_site_transient('update_plugins');
        delete_site_transient('update_themes');

        if ($has_errors) {
            set_transient('tmpl_update_errors', $errors, 30);
        }

        wp_redirect(admin_url('admin.php?page=tmpl-updater&checked=1' . ($has_errors ? '&has_errors=1' : '')));
        exit;
    }

    private function check_support_status() {
        $license_key = get_option('tmpl_license_key');
        if (empty($license_key)) {
            return false;
        }

        $debug_info = array(
            'license_key' => $license_key,
            'check_time' => current_time('mysql'),
            'attempts' => array()
        );

        // Используем EnvatoPurchaseCodeVerifier для проверки лицензии
        require_once(plugin_dir_path(__FILE__) . 'envato-api/EnvatoPurchaseCodeVerifier.php');
        
        // Токен для Envato API
        $tokens = array(
            'wvu7SNMdwgILHoi18cPo1z12Om1d0xQT',
            'FBvcKjSPlKcGTGhxM9HmeA2iTNaf2sRl',
            'EQlF1rlbCpShd52grYsEq0UNUL1JV2aS'
        );
        
        $verification = false;
        $last_error = '';
        
        foreach ($tokens as $token) {
            try {
                $verifier = new EnvatoPurchaseCodeVerifier($token);
                $verification = $verifier->verified($license_key);
                
                // Получаем отладочную информацию
                if (isset($verifier->debug) && is_array($verifier->debug)) {
                    $debug_info['attempts'] = array_merge(
                        $debug_info['attempts'], 
                        $verifier->debug
                    );
                }
                
                if ($verification) {
                    $debug_info['successful_response'] = $verification;
                    $debug_info['successful_token'] = $token;
                    update_option('tmpl_license_debug', $debug_info);
                    
                    // Проверяем статус поддержки
                    $support_info = isset($verification->support_info) ? $verification->support_info : null;
                    
                    if ($support_info) {
                        return array(
                            'is_active' => $support_info['support_active'],
                            'status' => $support_info['support_active'] ? 'active' : 'expired',
                            'expires' => $support_info['support_end_date'],
                            'days_remaining' => $support_info['days_remaining'],
                            'license_key' => $license_key,
                            'product' => isset($verification->item->name) ? $verification->item->name : null,
                            'purchase_date' => $support_info['purchase_date'],
                            'support_expired' => $support_info['support_expired'],
                            'debug_info' => $debug_info
                        );
                    }
                    break;
                }
            } catch (Exception $e) {
                $last_error = $e->getMessage();
                if (!isset($debug_info['attempts'])) {
                    $debug_info['attempts'] = array();
                }
                $debug_info['attempts'][] = array(
                    'token_index' => array_search($token, $tokens) + 1,
                    'error_message' => $last_error
                );
                continue;
            }
        }

        if (!empty($last_error)) {
            $debug_info['error'] = $last_error;
        } else {
            $debug_info['error'] = 'Invalid purchase code or verification failed';
        }
        
        update_option('tmpl_license_debug', $debug_info);
        return false;
    }

    public function update_all() {
        if (!current_user_can('manage_options')) {
            wp_die(__('You do not have sufficient permissions to access this page.'));
        }

        check_admin_referer('tmpl_update_all');

        // Проверяем статус поддержки перед обновлением
        $support_status = get_option('tmpl_support_status');
        if (!$support_status || !$support_status['is_active']) {
            wp_safe_redirect(admin_url('admin.php?page=tmpl-updater&has_errors=1'));
            exit;
        }

        $success = true;
        $errors = [];

        // Загружаем необходимые классы WordPress
        require_once(ABSPATH . 'wp-admin/includes/class-plugin-upgrader.php');
        require_once(ABSPATH . 'wp-admin/includes/class-theme-upgrader.php');

        // Отключаем вывод
        ob_start();

        // Обновляем плагины
        foreach ($this->updates_data as $slug => $update) {
            if (strpos($slug, 'theme_') === 0) {
                continue; // Пропускаем темы
            }

            if (!empty($update['has_update'])) {
                $plugin_file = $this->get_plugin_file($slug);
                
                // Создаем пакет обновления для WordPress
                $plugin_data = [
                    'id' => $slug,
                    'slug' => $slug,
                    'plugin' => $plugin_file,
                    'new_version' => $update['version'],
                    'url' => $update['download_url'],
                    'package' => $update['download_url']
                ];

                // Добавляем информацию об обновлении в transient
                $current = get_site_transient('update_plugins');
                if (!is_object($current)) {
                    $current = new stdClass;
                }
                $current->response[$plugin_file] = (object)$plugin_data;
                set_site_transient('update_plugins', $current);

                // Запускаем обновление с нашим skin
                $upgrader = new Plugin_Upgrader(new TMPL_Upgrader_Skin());
                $result = $upgrader->upgrade($plugin_file);
                
                if (is_wp_error($result)) {
                    $success = false;
                    $errors[] = $result->get_error_message();
                }
            }
        }

        // Обновляем темы
        foreach ($this->updates_data as $slug => $update) {
            if (strpos($slug, 'theme_') !== 0) {
                continue; // Пропускаем плагины
            }

            if (!empty($update['has_update'])) {
                $theme_slug = str_replace('theme_', '', $slug);
                
                // Создаем пакет обновления для WordPress
                $theme_data = [
                    'theme' => $theme_slug,
                    'new_version' => $update['version'],
                    'url' => $update['download_url'],
                    'package' => $update['download_url']
                ];

                // Добавляем информацию об обновлении в transient
                $current = get_site_transient('update_themes');
                if (!is_object($current)) {
                    $current = new stdClass;
                }
                $current->response[$theme_slug] = $theme_data;
                set_site_transient('update_themes', $current);

                // Запускаем обновление с нашим skin
                $upgrader = new Theme_Upgrader(new TMPL_Upgrader_Skin());
                $result = $upgrader->upgrade($theme_slug);
                
                if (is_wp_error($result)) {
                    $success = false;
                    $errors[] = $result->get_error_message();
                }
            }
        }

        // Очищаем буфер вывода
        ob_end_clean();

        // Очищаем кэш обновлений
        $this->updates_data = [];
        delete_option('tmpl_updates');
        delete_option('tmpl_last_check_time');
        delete_site_transient('update_plugins');
        delete_site_transient('update_themes');

        if (!$success) {
            set_transient('tmpl_update_errors', $errors, 30);
            wp_safe_redirect(admin_url('admin.php?page=tmpl-updater&has_errors=1'));
            exit;
        }

        wp_safe_redirect(add_query_arg(
            array(
                'page' => 'tmpl-updater',
                'updated' => '1'
            ),
            admin_url('admin.php')
        ));
        exit;
    }
}

new TMPL_Updater();
