<?php
if (!defined('ABSPATH')) {
    exit;
}

$support_status = get_option('tmpl_support_status');
$updates = get_option('tmpl_updates');
$license_key = get_option('tmpl_license_key');
$last_check_time = get_option('tmpl_last_check_time');
$debug_info = get_option('tmpl_debug_info', []);

$is_verified = !empty($license_key) && $support_status !== false; // Лицензия проверена
$is_support_active = $support_status && isset($support_status['is_active']) && $support_status['is_active'];

if (isset($_GET['has_errors'])) {
    $errors = get_transient('tmpl_update_errors');
    if ($errors) {
        echo '<div class="notice notice-error"><p>' . implode('<br>', $errors) . '</p></div>';
    }
}

if (isset($_GET['license']) && $_GET['license'] === 'verified') {
    echo '<div class="notice notice-success"><p>' . __('License verified successfully.', 'tmpl-updater') . '</p></div>';
} elseif (isset($_GET['license']) && $_GET['license'] === 'deleted') {
    echo '<div class="notice notice-success"><p>' . __('License deleted successfully.', 'tmpl-updater') . '</p></div>';
} elseif (isset($_GET['updated']) && $_GET['updated'] === '1') {
    echo '<div class="notice notice-success"><p>' . __('Updates installed successfully.', 'tmpl-updater') . '</p></div>';
} elseif (isset($_GET['checked']) && $_GET['checked'] === '1') {
    echo '<div class="notice notice-success"><p>' . __('Updates checked successfully.', 'tmpl-updater') . '</p></div>';
}
?>

<div class="wrap">
    <h1><?php echo esc_html__('TMPL Updater', 'tmpl-updater'); ?></h1>
    
    <div class="notice notice-warning">
        <p>
            <strong>⚠️ Important:</strong> Before performing any updates, please make sure to create a backup of your website files and database on your hosting. 
            This will allow you to restore your site if any issues occur during the update process.
        </p>
    </div>

    <?php if (isset($_GET['verified'])): ?>
        <div class="notice notice-success">
            <p><?php _e('License key verified successfully!', 'tmpl-updater'); ?></p>
        </div>
    <?php endif; ?>

    <?php if (isset($_GET['deleted'])): ?>
        <div class="notice notice-success">
            <p><?php _e('License key removed successfully!', 'tmpl-updater'); ?></p>
        </div>
    <?php endif; ?>

    <?php if (isset($_GET['error'])): ?>
        <div class="notice notice-error">
            <p>
                <?php
                switch ($_GET['error']) {
                    case 'empty_license':
                        _e('Пожалуйста, введите лицензионный ключ.', 'tmpl-updater');
                        break;
                    case 'invalid_license':
                        _e('Неверный лицензионный ключ. Пожалуйста, проверьте и попробуйте снова.', 'tmpl-updater');
                        break;
                    case 'invalid_product':
                        _e('Этот лицензионный ключ не принадлежит продукту Templines.', 'tmpl-updater');
                        break;
                    case 'check_limit':
                        _e('Вы достигли максимального количества проверок обновлений на сегодня. Пожалуйста, попробуйте завтра.', 'tmpl-updater');
                        break;
                    default:
                        _e('Произошла ошибка. Пожалуйста, попробуйте снова.', 'tmpl-updater');
                }
                ?>
            </p>
        </div>
    <?php endif; ?>

    <?php if (isset($_GET['checked'])): ?>
        <div class="notice notice-success">
            <p><?php _e('Updates checked successfully!', 'tmpl-updater'); ?></p>
        </div>
    <?php endif; ?>

    <?php if (isset($_GET['updated'])): ?>
        <div class="notice notice-success">
            <p><?php _e('Update completed successfully!', 'tmpl-updater'); ?></p>
        </div>
    <?php endif; ?>

    <?php if (isset($_GET['has_errors'])): ?>
        <?php 
        $errors = get_transient('tmpl_update_errors', []);
        if (!empty($errors)):
        ?>
            <div class="notice notice-error">
                <p><strong><?php _e('Some errors occurred during update:', 'tmpl-updater'); ?></strong></p>
                <ul>
                    <?php foreach ($errors as $error): ?>
                        <li><?php echo esc_html($error); ?></li>
                    <?php endforeach; ?>
                </ul>
            </div>
            <?php 
            // Очищаем ошибки после показа
            delete_transient('tmpl_update_errors');
            endif;
        ?>
    <?php endif; ?>

    <?php if (current_user_can('manage_options')): ?>
        <div class="card">
            <h2><?php esc_html_e('License Management', 'tmpl-updater'); ?></h2>
            
            <?php if (!empty($license_key)): ?>
                <p>
                    <?php esc_html_e('License Key:', 'tmpl-updater'); ?> 
                    <code><?php echo esc_html(substr($license_key, 0, 8) . '...' . substr($license_key, -4)); ?></code>
                    <?php 
                    $product_name = get_option('tmpl_product_name');
                    if ($product_name) {
                        echo ' | ' . esc_html__('Product:', 'tmpl-updater') . ' <strong>' . esc_html($product_name) . '</strong>';
                    }
                    ?>
                </p>

                <form method="post" action="<?php echo esc_url(admin_url('admin-post.php')); ?>" style="display: inline;">
                    <?php wp_nonce_field('tmpl_delete_license'); ?>
                    <input type="hidden" name="action" value="tmpl_delete_license">
                    <button type="submit" class="button button-link-delete">
                        <?php esc_html_e('Delete License', 'tmpl-updater'); ?>
                    </button>
                </form>
            <?php else: ?>
                <form method="post" action="<?php echo esc_url(admin_url('admin-post.php')); ?>">
                    <?php wp_nonce_field('tmpl_verify_license'); ?>
                    <input type="hidden" name="action" value="tmpl_verify_license">
                    <div class="license-input-group">
                        <input type="text" name="license_key" class="regular-text" 
                               placeholder="<?php esc_attr_e('Enter your Envato purchase code', 'tmpl-updater'); ?>"
                               required>
                        <button type="submit" class="button button-primary">
                            <?php esc_html_e('Verify License', 'tmpl-updater'); ?>
                        </button>
                    </div>
                    <p class="description">
                        <?php esc_html_e('Enter your Envato purchase code to enable theme and plugin updates.', 'tmpl-updater'); ?>
                        <a href="https://help.market.envato.com/hc/en-us/articles/202822600-Where-Is-My-Purchase-Code-" target="_blank">
                            <?php esc_html_e('Where is my purchase code?', 'tmpl-updater'); ?>
                        </a>
                    </p>
                </form>
            <?php endif; ?>
        </div>
    <?php endif; ?>

    <?php if ($is_verified): ?>
        <div class="tmpl-updater-container">
            <?php 
            // Показываем сообщения об ошибках при проверке обновлений
            if (isset($_GET['checked']) && isset($_GET['has_errors'])) {
                $errors = get_transient('tmpl_update_errors', []);
                foreach ($errors as $error) {
                    echo '<div class="notice notice-error"><p>' . esc_html($error) . '</p></div>';
                }
                delete_transient('tmpl_update_errors');
            }

            // Получаем данные об обновлениях и статус поддержки
            $updates = get_option('tmpl_updates', []);
            $has_updates = false;
            $support_status = get_option('tmpl_support_status', []);
            $last_check_time = get_option('tmpl_last_check_time');
            ?>

            <div class="card">
                <h2><?php esc_html_e('Available Updates', 'tmpl-updater'); ?></h2>

                <?php if ($last_check_time): ?>
                    <p class="last-check">
                        <?php printf(
                            __('Last checked: %s', 'tmpl-updater'),
                            date_i18n(get_option('date_format') . ' ' . get_option('time_format'), strtotime($last_check_time))
                        ); ?>
                    </p>
                <?php endif; ?>

                <?php if (!empty($updates)): ?>
                    <table class="widefat">
                        <thead>
                            <tr>
                                <th><?php esc_html_e('Name', 'tmpl-updater'); ?></th>
                                <th><?php esc_html_e('Current Version', 'tmpl-updater'); ?></th>
                                <th><?php esc_html_e('New Version', 'tmpl-updater'); ?></th>
                                <th><?php esc_html_e('Details', 'tmpl-updater'); ?></th>
                                <th><?php esc_html_e('Status', 'tmpl-updater'); ?></th>
                            </tr>
                        </thead>
                        <tbody>
                            <?php foreach ($updates as $slug => $update): ?>
                                <?php 
                                $is_theme = strpos($slug, 'theme_') === 0;
                                if ($update['has_update']) $has_updates = true;
                                ?>
                                <tr>
                                    <td><?php echo esc_html($update['name']); ?></td>
                                    <td><?php echo esc_html($update['current_version']); ?></td>
                                    <td><?php echo esc_html($update['version']); ?></td>
                                    <td>
                                        <?php if ($is_theme && !empty($update['details_url'])): ?>
                                            <a href="<?php echo esc_url($update['details_url']); ?>" target="_blank">
                                                <?php esc_html_e('View Changelog', 'tmpl-updater'); ?>
                                            </a>
                                        <?php elseif (!$is_theme && !empty($update['upgrade_notice'])): ?>
                                            <?php echo esc_html($update['upgrade_notice']); ?>
                                        <?php endif; ?>
                                    </td>
                                    <td>
                                        <?php if ($update['has_update']): ?>
                                            <span class="update-available"><?php esc_html_e('Update Available', 'tmpl-updater'); ?></span>
                                        <?php else: ?>
                                            <span class="up-to-date"><?php esc_html_e('Up to Date', 'tmpl-updater'); ?></span>
                                        <?php endif; ?>
                                    </td>
                                </tr>
                            <?php endforeach; ?>
                        </tbody>
                    </table>

                    <?php if ($has_updates): ?>
                        <?php if ($is_support_active): ?>
                            <p>
                                <form method="post" action="<?php echo esc_url(admin_url('admin-post.php')); ?>">
                                    <?php wp_nonce_field('tmpl_update_all'); ?>
                                    <input type="hidden" name="action" value="tmpl_update_all">
                                    <button type="submit" class="button button-primary">
                                        <?php esc_html_e('Update All', 'tmpl-updater'); ?>
                                    </button>
                                </form>
                            </p>
                        <?php else: ?>
                            <div class="notice notice-warning inline">
                                <p>
                                    <?php esc_html_e('Please renew your support period to get automatic updates.', 'tmpl-updater'); ?>
                                    <?php if (!empty($support_status['days_remaining'])): ?>
                                        <?php printf(
                                            __('Your support has expired %d days ago.', 'tmpl-updater'),
                                            abs($support_status['days_remaining'])
                                        ); ?>
                                    <?php endif; ?>
                                </p>
                            </div>
                        <?php endif; ?>
                    <?php endif; ?>
                <?php else: ?>
                    <p><?php esc_html_e('No updates available.', 'tmpl-updater'); ?></p>
                <?php endif; ?>

                <p>
                    <form method="post" action="<?php echo esc_url(admin_url('admin-post.php')); ?>">
                        <?php wp_nonce_field('tmpl_check_updates'); ?>
                        <input type="hidden" name="action" value="tmpl_check_updates">
                        <button type="submit" class="button">
                            <?php esc_html_e('Check Updates', 'tmpl-updater'); ?>
                        </button>
                    </form>
                </p>
            </div>

            <?php if (current_user_can('manage_options')): ?>
                <div class="card">
                    <h2><?php esc_html_e('Support Status', 'tmpl-updater'); ?></h2>
                    <?php if ($is_support_active): ?>
                        <p class="support-active">
                            <?php 
                            if (!empty($support_status['days_remaining'])) {
                                printf(
                                    __('Your support is active. %d days remaining.', 'tmpl-updater'),
                                    $support_status['days_remaining']
                                );
                            } else {
                                _e('Your support is active.', 'tmpl-updater');
                            }
                            ?>
                        </p>
                    <?php else: ?>
                        <p class="support-expired">
                            <?php 
                            if (!empty($support_status['days_remaining'])) {
                                printf(
                                    __('Your support has expired %d days ago.', 'tmpl-updater'),
                                    abs($support_status['days_remaining'])
                                );
                            } else {
                                _e('Your support has expired.', 'tmpl-updater');
                            }
                            ?>
                        </p>
                    <?php endif; ?>
                </div>
            <?php endif; ?>
        </div>
    <?php else: ?>
        <div class="notice notice-warning">
            <p><?php esc_html_e('Please enter a valid license key to enable automatic updates and support status.', 'tmpl-updater'); ?></p>
        </div>
    <?php endif; ?>

    <?php if (!$is_verified): ?>
        <div class="notice notice-warning">
            <p><?php esc_html_e('Please enter a valid license key to enable automatic updates and support status.', 'tmpl-updater'); ?></p>
        </div>
    <?php endif; ?>

    <style>
    .card {
        background: #fff;
        border: 1px solid #ccd0d4;
        padding: 20px;
        margin-top: 20px;
        box-shadow: 0 1px 1px rgba(0,0,0,.04);
    }
    .update-available {
        color: #d63638;
        font-weight: bold;
    }
    .up-to-date {
        color: #00a32a;
    }
    .support-active {
        color: #00a32a;
        font-weight: bold;
    }
    .support-expired {
        color: #d63638;
        font-weight: bold;
    }
    .notice.inline {
        margin: 15px 0;
        padding: 10px;
    }
    table {
        margin: 20px 0;
    }
    form {
        margin: 20px 0;
    }
    .last-check {
        color: #666;
        font-style: italic;
        margin-bottom: 15px;
    }
    .license-input-group {
        display: flex;
        gap: 10px;
        align-items: center;
        margin-bottom: 10px;
    }
    .license-input-group input[type="text"] {
        flex: 1;
    }
    .button-link-delete {
        color: #dc3232;
        text-decoration: none;
    }
    .button-link-delete:hover {
        color: #dc3232;
        text-decoration: underline;
    }
    .tmpl-status-active {
        color: #28a745;
        font-weight: bold;
    }
    .tmpl-status-expired {
        color: #dc3545;
        font-weight: bold;
    }
    </style>
</div>
